@@ -1,8 +1,6 @@
 # --
 # Kernel/GenericInterface/Mapping.pm - GenericInterface data mapping interface
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: Mapping.pm,v 1.18.2.1 2012-07-30 23:33:18 ep Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,8 +14,7 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsHashRefWithData IsStringWithData);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.18.2.1 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -174,8 +171,9 @@ sub Map {
 
     # check data - only accept undef or hash ref
     if ( defined $Param{Data} && ref $Param{Data} ne 'HASH' ) {
-        return $Self->{DebuggerObject}
-            ->Error( Summary => 'Got Data but it is not a hash ref in Mapping handler!' );
+        return $Self->{DebuggerObject}->Error(
+            Summary => 'Got Data but it is not a hash ref in Mapping handler!'
+        );
     }
 
     # return if data is empty
@@ -203,9 +201,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.18.2.1 $ $Date: 2012-07-30 23:33:18 $
-
-=cut
