@@ -175,8 +175,10 @@ sub Run {
                     Value => $Ticket{Number},
                 );
                 $Output .= $Self->{LayoutObject}->Warning(
-                    Message => 'Sorry, you need to be the ticket owner to perform this action.',
-                    Comment => 'Please change the owner first.',
+                    Message => $Self->{LayoutObject}->{LanguageObject}
+                        ->Get('Sorry, you need to be the ticket owner to perform this action.'),
+                    Comment => $Self->{LayoutObject}->{LanguageObject}
+                        ->Get('Please change the owner first.'),
                 );
                 $Output .= $Self->{LayoutObject}->Footer(
                     Type => 'Small',
@@ -262,8 +264,10 @@ sub Run {
 
     # rewrap body if no rich text is used
     if ( $GetParam{Body} && !$Self->{LayoutObject}->{BrowserRichText} ) {
-        my $Size = $Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote') || 70;
-        $GetParam{Body} =~ s/(^>.+|.{4,$Size})(?:\s|\z)/$1\n/gm;
+        $GetParam{Body} = $Self->{LayoutObject}->WrapPlainText(
+            MaxCharacters => $Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote'),
+            PlainText     => $GetParam{Body},
+        );
     }
 
     if ( $Self->{Subaction} eq 'Store' ) {
@@ -672,7 +676,7 @@ sub Run {
                 );
             }
 
-            my $From = "$Self->{UserFirstname} $Self->{UserLastname} <$Self->{UserEmail}>";
+            my $From = "\"$Self->{UserFirstname} $Self->{UserLastname}\" <$Self->{UserEmail}>";
             my @NotifyUserIDs = ( @{ $Self->{InformUserID} }, @{ $Self->{InvolvedUserID} } );
             $ArticleID = $Self->{TicketObject}->ArticleCreate(
                 TicketID                        => $Self->{TicketID},
@@ -921,6 +925,7 @@ sub Run {
             my $ACL = $Self->{TicketObject}->TicketAcl(
                 %GetParam,
                 Action        => $Self->{Action},
+                TicketID      => $Self->{TicketID},
                 QueueID       => $QueueID,
                 ReturnType    => 'Ticket',
                 ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
@@ -1171,7 +1176,7 @@ sub _Mask {
             Data  => \%Type,
             Name  => 'TypeID',
             SelectedID   => $Param{TypeID},
-            PossibleNone => 0,
+            PossibleNone => 1,
             Sort         => 'AlphanumericValue',
             Translation  => 0,
         );
@@ -1678,7 +1683,14 @@ sub _GetResponsible {
         Type  => 'Long',
         Valid => 1,
     );
-    if ( $Param{QueueID} && !$Param{AllUsers} ) {
+
+    # show all users
+    if ( $Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
+        %ShownUsers = %AllGroupsMembers;
+    }
+
+    # show only users with responsible or rw pemissions in the queue
+    elsif ( $Param{QueueID} && !$Param{AllUsers} ) {
         my $GID = $Self->{QueueObject}->GetQueueGroupID(
             QueueID => $Param{NewQueueID} || $Param{QueueID}
         );
@@ -1714,7 +1726,14 @@ sub _GetOwners {
         Type  => 'Long',
         Valid => 1,
     );
-    if ( $Param{QueueID} && !$Param{AllUsers} ) {
+
+    # show all users
+    if ( $Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
+        %ShownUsers = %AllGroupsMembers;
+    }
+
+    # show only users with owner or rw pemissions in the queue
+    elsif ( $Param{QueueID} && !$Param{AllUsers} ) {
         my $GID = $Self->{QueueObject}->GetQueueGroupID(
             QueueID => $Param{NewQueueID} || $Param{QueueID}
         );
