@@ -197,8 +197,10 @@ sub Form {
                     Type => 'Small',
                 );
                 $Output .= $Self->{LayoutObject}->Warning(
-                    Message => 'Sorry, you need to be the ticket owner to perform this action.',
-                    Comment => 'Please change the owner first.',
+                    Message => $Self->{LayoutObject}->{LanguageObject}
+                        ->Get('Sorry, you need to be the ticket owner to perform this action.'),
+                    Comment => $Self->{LayoutObject}->{LanguageObject}
+                        ->Get('Please change the owner first.'),
                 );
                 $Output .= $Self->{LayoutObject}->Footer(
                     Type => 'Small',
@@ -543,7 +545,7 @@ sub SendEmail {
     my $NextState = $StateData{Name};
 
     # check pending date
-    if ( $StateData{TypeName} && $StateData{TypeName} =~ /^pending/i ) {
+    if ( defined $StateData{TypeName} && $StateData{TypeName} =~ /^pending/i ) {
         if ( !$Self->{TimeObject}->Date2SystemTime( %GetParam, Second => 0 ) ) {
             $Error{'DateInvalid'} = 'ServerError';
         }
@@ -937,7 +939,7 @@ sub SendEmail {
     $Self->{UploadCacheObject}->FormIDRemove( FormID => $GetParam{FormID} );
 
     # redirect
-    if ( $StateData{TypeName} =~ /^close/i ) {
+    if ( defined $StateData{TypeName} && $StateData{TypeName} =~ /^close/i ) {
         return $Self->{LayoutObject}->PopupClose(
             URL => ( $Self->{LastScreenView} || 'Action=AgentDashboard' ),
         );
@@ -1507,7 +1509,12 @@ sub _GetExtendedParams {
                 || '';
             if ($CustomerElement) {
 
-                $GetParam{To} .= $CustomerElement . ',';
+                if ( $GetParam{To} ) {
+                    $GetParam{To} .= ', ' . $CustomerElement;
+                }
+                else {
+                    $GetParam{To} = $CustomerElement;
+                }
 
                 # check email address
                 my $CustomerErrorMsg = 'CustomerGenericServerErrorMsg';
@@ -1569,7 +1576,12 @@ sub _GetExtendedParams {
 
             if ($CustomerElementCc) {
 
-                $GetParam{Cc} .= $CustomerElementCc . ',';
+                if ( $GetParam{Cc} ) {
+                    $GetParam{Cc} .= ', ' . $CustomerElementCc;
+                }
+                else {
+                    $GetParam{Cc} = $CustomerElementCc;
+                }
 
                 # check email address
                 my $CustomerErrorMsgCc = 'CustomerGenericServerErrorMsg';
@@ -1631,7 +1643,12 @@ sub _GetExtendedParams {
 
             if ($CustomerElementBcc) {
 
-                $GetParam{Bcc} .= $CustomerElementBcc . ',';
+                if ( $GetParam{Bcc} ) {
+                    $GetParam{Bcc} .= ', ' . $CustomerElementBcc;
+                }
+                else {
+                    $GetParam{Bcc} = $CustomerElementBcc;
+                }
 
                 # check email address
                 my $CustomerErrorMsgBcc = 'CustomerGenericServerErrorMsg';
