@@ -14,8 +14,7 @@ use warnings;
 
 use Kernel::System::CustomerCompany;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.72 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -362,6 +361,8 @@ sub CustomerUserDataGet {
             %Company = $Self->{CustomerCompanyObject}->CustomerCompanyGet(
                 CustomerID => $Customer{UserCustomerID},
             );
+            
+            $Company{CustomerCompanyValidID} = $Company{ValidID};
         }
 
         # return customer data
@@ -728,9 +729,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.72 $ $Date: 2012-11-20 15:33:43 $
-
-=cut
