@@ -1,8 +1,6 @@
 # --
 # Kernel/System/DynamicField/Backend/Date.pm - Delegate for DynamicField Date backend
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: Date.pm,v 1.50.2.1 2012-05-10 19:19:15 cr Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,9 +17,6 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::Time;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.50.2.1 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField::Backend::Date
@@ -229,9 +224,7 @@ sub EditFieldRender {
     }
 
     # extract the dynamic field value form the web request
-    # TransformDates is always needed from EditFieldRender Bug#8452
     my $FieldValues = $Self->EditFieldValueGet(
-        TransformDates       => 1,
         ReturnValueStructure => 1,
         %Param,
     );
@@ -521,7 +514,7 @@ sub SearchFieldRender {
         $Value = \%DefaultValue;
     }
 
-    # get the field value, this fuction is always called after the profile is loaded
+    # get the field value, this function is always called after the profile is loaded
     my $FieldValues = $Self->SearchFieldValueGet(
         %Param,
     );
@@ -581,7 +574,7 @@ EOF
 
     my $AdditionalText;
     if ( $Param{UseLabelHints} ) {
-        $AdditionalText = 'Between';
+        $AdditionalText = 'between';
     }
 
     # call EditLabelRender on the common backend
@@ -876,10 +869,18 @@ sub HistoricalValuesGet {
         ValueType => 'DateTime',
     );
 
-    # retrun the historical values from database
+    # return the historical values from database
     return $HistoricalValues;
 }
 
+sub ValueLookup {
+    my ( $Self, %Param ) = @_;
+
+    my $Value = defined $Param{Key} ? $Param{Key} : '';
+
+    return $Value;
+}
+
 1;
 
 =back
@@ -893,9 +894,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$$
-
-=cut
