@@ -220,7 +220,7 @@ sub EditFieldRender {
     my $FieldName   = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
     my $FieldLabel  = $Param{DynamicFieldConfig}->{Label};
 
-    my $Value = '';
+    my $Value;
 
     # set the field value or default
     if ( $Param{UseDefaultValue} ) {
@@ -228,6 +228,16 @@ sub EditFieldRender {
     }
     $Value = $Param{Value} if defined $Param{Value};
 
+    # check if a value in a template (GenericAgent etc.)
+    # is configured for this dynamic field
+    if (
+        IsHashRefWithData( $Param{Template} )
+        && defined $Param{Template}->{$FieldName}
+        )
+    {
+        $Value = $Param{Template}->{$FieldName};
+    }
+
     #d extract the dynamic field value form the web request
     my $FieldValue = $Self->EditFieldValueGet(
         %Param,
@@ -251,19 +261,21 @@ sub EditFieldRender {
     $FieldClass .= ' ServerError' if $Param{ServerError};
 
     # set PossibleValues
-    my $SelectionData = $FieldConfig->{PossibleValues};
+    my $PossibleValues = $FieldConfig->{PossibleValues};
 
     # use PossibleValuesFilter if defined
-    $SelectionData = $Param{PossibleValuesFilter}
+    $PossibleValues = $Param{PossibleValuesFilter}
         if defined $Param{PossibleValuesFilter};
 
     # check value
-    my @Values;
-    if ( ref $Value eq 'ARRAY' ) {
-        @Values = @{$Value};
-    }
-    else {
-        @Values = ($Value);
+    my $SelectedValuesArrayRef;
+    if ( defined $Value ) {
+        if ( ref $Value eq 'ARRAY' ) {
+            $SelectedValuesArrayRef = $Value;
+        }
+        else {
+            $SelectedValuesArrayRef = [$Value];
+        }
     }
 
     # set PossibleNone attribute
@@ -276,9 +288,9 @@ sub EditFieldRender {
     }
 
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
-        Data => $SelectionData || {},
+        Data => $PossibleValues || {},
         Name => $FieldName,
-        SelectedID   => \@Values,
+        SelectedID   => $SelectedValuesArrayRef,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
         PossibleNone => $FieldPossibleNone,
         Class        => $FieldClass,
@@ -687,10 +699,14 @@ sub SearchFieldParameterBuild {
 
                 # set the display value
                 my $DisplayItem = $Param{DynamicFieldConfig}->{Config}->{PossibleValues}->{$Item};
-                if ( $Param{DynamicFieldConfig}->{Config}->{TranslatableValues} ) {
 
-                    # translate the value
-                    $DisplayItem = $Param{LayoutObject}->{LanguageObject}->Get($DisplayValue);
+                # translate the value
+                if (
+                    $Param{DynamicFieldConfig}->{Config}->{TranslatableValues}
+                    && defined $Param{LayoutObject}
+                    )
+                {
+                    $DisplayItem = $Param{LayoutObject}->{LanguageObject}->Get($DisplayItem);
                 }
 
                 push @DisplayItemList, $DisplayItem;
@@ -704,9 +720,12 @@ sub SearchFieldParameterBuild {
             # set the display value
             $DisplayValue = $Param{DynamicFieldConfig}->{PossibleValues}->{$Value};
 
-            if ( $Param{DynamicFieldConfig}->{Config}->{TranslatableValues} ) {
-
-                # translate the value
+            # translate the value
+            if (
+                $Param{DynamicFieldConfig}->{Config}->{TranslatableValues}
+                && defined $Param{LayoutObject}
+                )
+            {
                 $DisplayValue = $Param{LayoutObject}->{LanguageObject}->Get($DisplayValue);
             }
         }
@@ -887,6 +906,8 @@ sub ObjectMatch {
     VALUE:
     for my $AttributeValue ( @{ $Param{ObjectAttributes}->{$FieldName} } ) {
 
+        next VALUE if !defined $AttributeValue;
+
         # only need to match one
         if ( $Param{Value} eq $AttributeValue ) {
             $Match = 1;
