@@ -14,6 +14,7 @@ use warnings;
 
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
+use Kernel::System::State;
 use Kernel::System::VariableCheck qw(:all);
 
 =head1 NAME
@@ -107,6 +108,15 @@ sub new {
     # create additional objects
     $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
     $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+    $Self->{StateObject}        = Kernel::System::State->new(%Param);
+
+    my %PendingStates = $Self->{StateObject}->StateGetStatesByType(
+        StateType => [ 'pending auto', 'pending reminder' ],
+        Result => 'HASH',
+    );
+
+    $Self->{PendingStateList} = \%PendingStates || {};
+    $Self->{CurrentSystemTime} = $Self->{TimeObject}->SystemTime();
 
     # get the dynamic fields for ticket object
     $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
@@ -296,24 +306,19 @@ sub JobRun {
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD
+            if !$DynamicFieldSearchTemplate{ 'Search_DynamicField_' . $DynamicFieldConfig->{Name} };
 
-        # get field value from the information extracted from Generic Agent job
-        my $Value = $Self->{BackendObject}->SearchFieldValueGet(
+        # extract the dynamic field value form the Generic Agent Job
+        my $SearchParameter = $Self->{BackendObject}->SearchFieldParameterBuild(
             DynamicFieldConfig => $DynamicFieldConfig,
             Profile            => \%DynamicFieldSearchTemplate,
-        ) || '';
+        );
 
-        if ($Value) {
-
-            # get search attibutes
-            my $SearchParameter = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
-                DynamicFieldConfig => $DynamicFieldConfig,
-                Value              => $Value,
-            );
-
-            # add search attribute to the search structure
+        # set search parameter
+        if ( defined $SearchParameter ) {
             $DynamicFieldSearchParameters{ 'DynamicField_' . $DynamicFieldConfig->{Name} }
-                = $SearchParameter;
+                = $SearchParameter->{Parameter};
         }
     }
 
@@ -322,10 +327,12 @@ sub JobRun {
     # escalation tickets
     if ( $Job{Escalation} ) {
 
+        # Find all tickets which will escalate within the next five days.
+        #   The notification module will determine if a notification must be sent out or not.
         my @Tickets = $Self->{TicketObject}->TicketSearch(
             Result                           => 'ARRAY',
             Limit                            => 100,
-            TicketEscalationTimeOlderMinutes => -( 3 * 8 * 60 ),       # 3 days, roughly
+            TicketEscalationTimeOlderMinutes => -( 5 * 24 * 60 ),
             Permission                       => 'rw',
             UserID                           => $Param{UserID} || 1,
         );
@@ -871,6 +878,8 @@ sub _JobRunTicket {
         }
     }
 
+    my $IsPendingState;
+
     # set new state
     if ( $Param{Config}->{New}->{State} ) {
         if ( $Self->{NoticeSTDOUT} ) {
@@ -881,6 +890,9 @@ sub _JobRunTicket {
             UserID   => $Param{UserID},
             State    => $Param{Config}->{New}->{State},
         );
+
+        $IsPendingState
+            = grep { $_ eq $Param{Config}->{New}->{State} } values %{ $Self->{PendingStateList} };
     }
     if ( $Param{Config}->{New}->{StateID} ) {
         if ( $Self->{NoticeSTDOUT} ) {
@@ -891,6 +903,43 @@ sub _JobRunTicket {
             UserID   => $Param{UserID},
             StateID  => $Param{Config}->{New}->{StateID},
         );
+
+        $IsPendingState
+            = grep { $_ == $Param{Config}->{New}->{StateID} } keys %{ $Self->{PendingStateList} };
+    }
+
+    # set pending time, if new state is pending state
+    if ($IsPendingState) {
+        if ( $Param{Config}->{New}->{PendingTime} ) {
+
+            # pending time
+            my $PendingTime = $Param{Config}->{New}->{PendingTime};
+
+            # calculate pending time based on hours, minutes, years...
+            if ( $Param{Config}->{New}->{PendingTimeType} ) {
+                $PendingTime *= $Param{Config}->{New}->{PendingTimeType};
+            }
+
+            # add systemtime
+            $PendingTime += $Self->{CurrentSystemTime};
+
+            # get date
+            my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay )
+                = $Self->{TimeObject}->SystemTime2Date(
+                SystemTime => $PendingTime,
+                );
+
+            # set pending time
+            $Self->{TicketObject}->TicketPendingTimeSet(
+                Year     => $Year,
+                Month    => $Month,
+                Day      => $Day,
+                Hour     => $Hour,
+                Minute   => $Min,
+                TicketID => $Param{TicketID},
+                UserID   => $Param{UserID},
+            );
+        }
     }
 
     # set customer id and customer user
@@ -1097,7 +1146,17 @@ sub _JobRunTicket {
             TransformDates     => 0,
         );
 
-        if ( defined $Value && $Value ne '' ) {
+        # check if we got a value or an empty value if
+        # an empty value is configured as valid (PossibleNone)
+        # for the current dynamic field
+        if (
+            defined $Value
+            && (
+                $DynamicFieldConfig->{Config}->{PossibleNone}
+                || $Value ne ''
+            )
+            )
+        {
             my $Success = $Self->{BackendObject}->ValueSet(
                 DynamicFieldConfig => $DynamicFieldConfig,
                 ObjectID           => $Param{TicketID},
