@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Queue.pm - lib for queue functions
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Queue.pm,v 1.138 2012-04-17 19:07:54 mb Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -22,9 +20,6 @@ use Kernel::System::SysConfig;
 use Kernel::System::Time;
 use Kernel::System::Valid;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.138 $) [1];
-
 =head1 NAME
 
 Kernel::System::Queue - queue lib
@@ -624,7 +619,7 @@ add queue with attributes
         SolutionTime        => 580,         # (optional)
         SolutionNotify      => 80,          # (optional, notify agent if solution escalation is 80% reached)
         UnlockTimeout       => 480,         # (optional)
-        FollowUpId          => 3,           # possible (1), reject (2) or new ticket (3) (optional, default 0)
+        FollowUpID          => 3,           # possible (1), reject (2) or new ticket (3) (optional, default 0)
         FollowUpLock        => 0,           # yes (1) or no (0) (optional, default 0)
         DefaultSignKey      => 'key name',  # (optional)
         SystemAddressID     => 1,
@@ -980,7 +975,7 @@ sub QueueUpdate {
     my %AllQueue = $Self->QueueList( Valid => 0 );
     my %OldQueue = $Self->QueueGet( ID => $Param{QueueID} );
 
-    for ( keys %AllQueue ) {
+    for ( sort keys %AllQueue ) {
         if ( $AllQueue{$_} =~ /^\Q$Param{Name}\E$/i && $_ != $Param{QueueID} ) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
@@ -1017,7 +1012,7 @@ sub QueueUpdate {
     # updated all sub queue names
     my @ParentQueue = split( /::/, $OldQueue{Name} );
 
-    for my $QueueID ( keys %AllQueue ) {
+    for my $QueueID ( sort keys %AllQueue ) {
 
         my @SubQueue = split( /::/, $AllQueue{$QueueID} );
 
@@ -1174,9 +1169,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.138 $ $Date: 2012-04-17 19:07:54 $
-
-=cut
