@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Stats/Dynamic/TicketAccountedTime.pm - stats for accounted ticket time
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: TicketAccountedTime.pm,v 1.15 2012-02-28 10:38:01 jp Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -23,9 +21,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.15 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -394,6 +389,26 @@ sub GetObjectAttributes {
         unshift @ObjectAttributes, \%ObjectAttribute1;
     }
 
+    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+
+        my %ObjectAttribute = (
+            Name             => 'Archive Search',
+            UseAsXvalue      => 0,
+            UseAsValueSeries => 0,
+            UseAsRestriction => 1,
+            Element          => 'SearchInArchive',
+            Block            => 'SelectField',
+            Translation      => 1,
+            Values           => {
+                ArchivedTickets    => 'Archived tickets',
+                NotArchivedTickets => 'Unarchived tickets',
+                AllTickets         => 'All tickets',
+            },
+        );
+
+        push @ObjectAttributes, \%ObjectAttribute;
+    }
+
     if ( $Self->{ConfigObject}->Get('Stats::UseAgentElementInStats') ) {
 
         my @ObjectAttributeAdd = (
@@ -491,18 +506,25 @@ sub GetObjectAttributes {
 
         my $PossibleValuesFilter;
 
+        # convert possible values key => value to key => key for ACLs usign a Hash slice
+        my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} || {} };
+        @AclData{ keys %AclData } = keys %AclData;
+
         # set possible values filter from ACLs
         my $ACL = $Self->{TicketObject}->TicketAcl(
             Action        => 'AgentStats',
             Type          => 'DynamicField_' . $DynamicFieldConfig->{Name},
             ReturnType    => 'Ticket',
             ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-            Data          => $DynamicFieldConfig->{Config}->{PossibleValues} || {},
+            Data          => \%AclData || {},
             UserID        => 1,
         );
         if ($ACL) {
             my %Filter = $Self->{TicketObject}->TicketAclData();
-            $PossibleValuesFilter = \%Filter;
+
+            # convert Filer key => key back to key => value using map
+            %{$PossibleValuesFilter}
+                = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} } keys %Filter;
         }
 
         # get field html
@@ -665,7 +687,7 @@ sub ExportWrapper {
                 }
             }
             elsif (
-                $ElementName    eq 'OwnerIDs'
+                $ElementName eq 'OwnerIDs'
                 || $ElementName eq 'CreatedUserIDs'
                 || $ElementName eq 'ResponsibleIDs'
                 )
@@ -735,7 +757,7 @@ sub ImportWrapper {
             elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
                 my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
                 my %PriorityIDs;
-                for my $Key ( keys %PriorityList ) {
+                for my $Key ( sort keys %PriorityList ) {
                     $PriorityIDs{ $PriorityList{$Key} } = $Key;
                 }
                 ID:
@@ -755,7 +777,7 @@ sub ImportWrapper {
                 }
             }
             elsif (
-                $ElementName    eq 'OwnerIDs'
+                $ElementName eq 'OwnerIDs'
                 || $ElementName eq 'CreatedUserIDs'
                 || $ElementName eq 'ResponsibleIDs'
                 )
@@ -823,7 +845,7 @@ sub _ReportingValues {
         }
     }
 
-    for my $ParameterName ( keys %TicketSearch ) {
+    for my $ParameterName ( sort keys %TicketSearch ) {
         if ( $ParameterName =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
 
             # loop over the dynamic fields configured
@@ -849,6 +871,19 @@ sub _ReportingValues {
         }
     }
 
+    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+        $SearchAttributes->{SearchInArchive} ||= '';
+        if ( $SearchAttributes->{SearchInArchive} eq 'AllTickets' ) {
+            $TicketSearch{ArchiveFlags} = [ 'y', 'n' ];
+        }
+        elsif ( $SearchAttributes->{SearchInArchive} eq 'ArchivedTickets' ) {
+            $TicketSearch{ArchiveFlags} = ['y'];
+        }
+        else {
+            $TicketSearch{ArchiveFlags} = ['n'];
+        }
+    }
+
     if (%TicketSearch) {
 
         # get the involved tickets
