@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.CreateApacheStartupFile.pl - create optimal Apache startup file
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -43,7 +44,7 @@ sub PrintUsage {
     print <<"EOF";
 
 otrs.CreateApacheStartupFile.pl - update apache startup file for mod_perl
-Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 
 EOF
 }
@@ -68,7 +69,7 @@ EOF
     # Loop over all general system packages and include them
     #
     my $PackagesCode = '';
-    for my $Package ( GetPackageList( CommonObject => \%CommonObject ) ) {
+    foreach my $Package ( GetPackageList( CommonObject => \%CommonObject ) ) {
         $PackagesCode .= "use $Package;\n";
     }
 
@@ -79,7 +80,7 @@ EOF
 #!/usr/bin/perl
 # -\-
 # scripts/apache-perl-startup.pl - to load the modules if mod_perl is used
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # -\-
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -218,7 +219,7 @@ sub GetPackageList {
     }
 
     FILE:
-    for my $File ( sort @Files ) {
+    foreach my $File ( sort @Files ) {
         my $Package = CheckPerlPackage(
             CommonObject => \%CommonObject,
             Filename     => $File,
